// Map of old global non-color tokens used in V5 and their suitable replacement token in V6
// these V6 global tokens (if listed in tokensToPrefixWithT) will additionaly be prefixed with "t_" by the tokens-prefix-with-t rule
export const globalNonColorTokensMap = {
  global_BorderRadius_lg: "global_border_radius_large", // 30em -> 24px
  global_BorderRadius_sm: "global_border_radius_small", // 3px -> 6px (optionally global_border_radius_tiny = 4px)
  global_BorderWidth_lg: "global_border_width_extra_strong",
  global_BorderWidth_md: "global_border_width_strong",
  global_BorderWidth_sm: "global_border_width_regular",
  global_BorderWidth_xl: "global_border_width_extra_strong", // 4px -> 3px
  global_BoxShadow_inset: "SKIP", // NO SUITABLE REPLACEMENT, value: inset 0 0 0.625rem 0 rgba(3, 3, 3, 0.25)
  global_BoxShadow_lg: "global_box_shadow_lg",
  global_BoxShadow_lg_bottom: "global_box_shadow_lg_bottom",
  global_BoxShadow_lg_left: "global_box_shadow_lg_left",
  global_BoxShadow_lg_right: "global_box_shadow_lg_right",
  global_BoxShadow_lg_top: "global_box_shadow_lg_top",
  global_BoxShadow_md: "global_box_shadow_md",
  global_BoxShadow_md_bottom: "global_box_shadow_md_bottom",
  global_BoxShadow_md_left: "global_box_shadow_md_left",
  global_BoxShadow_md_right: "global_box_shadow_md_right",
  global_BoxShadow_md_top: "global_box_shadow_md_top",
  global_BoxShadow_sm: "global_box_shadow_sm",
  global_BoxShadow_sm_bottom: "global_box_shadow_sm_bottom",
  global_BoxShadow_sm_left: "global_box_shadow_sm_left",
  global_BoxShadow_sm_right: "global_box_shadow_sm_right",
  global_BoxShadow_sm_top: "global_box_shadow_sm_top",
  global_BoxShadow_xl: "global_box_shadow_lg", // no 'xl' shadow available, will use 'lg'
  global_BoxShadow_xl_bottom: "global_box_shadow_lg_bottom",
  global_BoxShadow_xl_left: "global_box_shadow_lg_left",
  global_BoxShadow_xl_right: "global_box_shadow_lg_right",
  global_BoxShadow_xl_top: "global_box_shadow_lg_top",
  global_FontFamily_heading: "global_font_family_heading", // (optionally use global_font_family_heading_legacy)
  global_FontFamily_heading_vf: "global_font_family_heading", // (optionally use global_font_family_heading_legacy)
  global_FontFamily_monospace: "global_font_family_mono", // (optionally use global_font_family_mono_legacy)
  global_FontFamily_monospace_vf: "global_font_family_mono", // (optionally use global_font_family_mono_legacy)
  global_FontFamily_text: "global_font_family_body", // (optionally use global_font_family_body_legacy)
  global_FontFamily_text_vf: "global_font_family_body", // (optionally use global_font_family_body_legacy)
  global_FontSize_2xl: "global_font_size_2xl", // 1.5rem -> 1.375rem
  global_FontSize_3xl: "global_font_size_3xl",
  global_FontSize_4xl: "global_font_size_4xl",
  global_FontSize_lg: "global_font_size_lg",
  global_FontSize_md: "global_font_size_md",
  global_FontSize_sm: "global_font_size_sm",
  global_FontSize_xl: "global_font_size_xl",
  global_FontSize_xs: "global_font_size_xs",
  global_FontWeight_bold: "global_font_weight_heading_bold", // or global_font_weight_heading_default
  global_FontWeight_normal: "global_font_weight_body_default",
  global_LineHeight_md: "global_font_line_height_body",
  global_LineHeight_sm: "global_font_line_height_heading",
  global_ListStyle: "global_list_style",
  global_TimingFunction: "global_transition_timing_function",
  global_Transition: "global_transition",
  global_TransitionDuration: "global_transition_duration",
  global_ZIndex_2xl: "global_z_index_2xl",
  global_ZIndex_lg: "global_z_index_lg",
  global_ZIndex_md: "global_z_index_md",
  global_ZIndex_sm: "global_z_index_sm",
  global_ZIndex_xl: "global_z_index_xl",
  global_ZIndex_xs: "global_z_index_xs",
  global_arrow_width: "SKIP", // NO SUITABLE REPLACEMENT, value: 0.9375rem
  global_arrow_width_lg: "SKIP", // NO SUITABLE REPLACEMENT, value: 1.5625rem
  global_font_path: "SKIP", // NO SUITABLE REPLACEMENT, value: "./assets/fonts"
  global_fonticon_path: "SKIP", // NO SUITABLE REPLACEMENT, value: "./assets/pficon"
  global_gutter: "global_spacer_gutter_default",
  global_gutter_md: "global_spacer_lg",
  global_height_breakpoint_2xl: "global_breakpoint_height_2xl",
  global_height_breakpoint_lg: "global_breakpoint_height_lg",
  global_height_breakpoint_md: "global_breakpoint_height_md",
  global_height_breakpoint_sm: "global_breakpoint_height_sm",
  global_height_breakpoint_xl: "global_breakpoint_height_xl",
  global_icon_FontSize_lg: "global_icon_size_font_2xl", // 1.5rem -> 1.375rem
  global_icon_FontSize_md: "global_icon_size_font_md",
  global_icon_FontSize_sm: "global_icon_size_font_xs",
  global_icon_FontSize_xl: "global_icon_size_font_4xl", // 3.375rem -> 2.25rem
  global_link_TextDecoration: "global_text_decoration_link_line_default", // optionally global_text_decoration_line_100 for no underline
  global_link_TextDecoration_hover: "global_text_decoration_link_line_hover",
  global_spacer_form_element: "global_spacer_xs", // 0.375rem -> 0.25rem (or global_spacer_sm = 0.5rem)
  global_target_size_MinHeight: "SKIP", // NO SUITABLE REPLACEMENT, value: 44px
  global_target_size_MinWidth: "SKIP", // NO SUITABLE REPLACEMENT, value: 44px
};

export const oldGlobalNonColorTokens = new Set(
  Object.keys(globalNonColorTokensMap)
);

export const oldGlobalColorTokens = new Set([
  "global_BackgroundColor_100",
  "global_BackgroundColor_150",
  "global_BackgroundColor_200",
  "global_BackgroundColor_dark_100",
  "global_BackgroundColor_dark_200",
  "global_BackgroundColor_dark_300",
  "global_BackgroundColor_dark_400",
  "global_BackgroundColor_dark_transparent_100",
  "global_BackgroundColor_dark_transparent_200",
  "global_BackgroundColor_light_100",
  "global_BackgroundColor_light_200",
  "global_BackgroundColor_light_300",
  "global_BorderColor_100",
  "global_BorderColor_200",
  "global_BorderColor_300",
  "global_BorderColor_dark_100",
  "global_BorderColor_light_100",
  "global_Color_100",
  "global_Color_200",
  "global_Color_300",
  "global_Color_400",
  "global_Color_dark_100",
  "global_Color_dark_200",
  "global_Color_light_100",
  "global_Color_light_200",
  "global_Color_light_300",
  "global_active_color_100",
  "global_active_color_200",
  "global_active_color_300",
  "global_active_color_400",
  "global_custom_color_100",
  "global_custom_color_200",
  "global_custom_color_300",
  "global_danger_color_100",
  "global_danger_color_200",
  "global_danger_color_300",
  "global_disabled_color_100",
  "global_disabled_color_200",
  "global_disabled_color_300",
  "global_icon_Color_dark",
  "global_icon_Color_dark_dark",
  "global_icon_Color_dark_light",
  "global_icon_Color_light",
  "global_icon_Color_light_dark",
  "global_icon_Color_light_light",
  "global_info_color_100",
  "global_info_color_200",
  "global_link_Color",
  "global_link_Color_dark",
  "global_link_Color_dark_hover",
  "global_link_Color_hover",
  "global_link_Color_light",
  "global_link_Color_light_hover",
  "global_link_Color_visited",
  "global_palette_black_100",
  "global_palette_black_1000",
  "global_palette_black_150",
  "global_palette_black_200",
  "global_palette_black_300",
  "global_palette_black_400",
  "global_palette_black_500",
  "global_palette_black_600",
  "global_palette_black_700",
  "global_palette_black_800",
  "global_palette_black_850",
  "global_palette_black_900",
  "global_palette_blue_100",
  "global_palette_blue_200",
  "global_palette_blue_300",
  "global_palette_blue_400",
  "global_palette_blue_50",
  "global_palette_blue_500",
  "global_palette_blue_600",
  "global_palette_blue_700",
  "global_palette_cyan_100",
  "global_palette_cyan_200",
  "global_palette_cyan_300",
  "global_palette_cyan_400",
  "global_palette_cyan_50",
  "global_palette_cyan_500",
  "global_palette_cyan_600",
  "global_palette_cyan_700",
  "global_palette_gold_100",
  "global_palette_gold_200",
  "global_palette_gold_300",
  "global_palette_gold_400",
  "global_palette_gold_50",
  "global_palette_gold_500",
  "global_palette_gold_600",
  "global_palette_gold_700",
  "global_palette_green_100",
  "global_palette_green_200",
  "global_palette_green_300",
  "global_palette_green_400",
  "global_palette_green_50",
  "global_palette_green_500",
  "global_palette_green_600",
  "global_palette_green_700",
  "global_palette_light_blue_100",
  "global_palette_light_blue_200",
  "global_palette_light_blue_300",
  "global_palette_light_blue_400",
  "global_palette_light_blue_500",
  "global_palette_light_blue_600",
  "global_palette_light_blue_700",
  "global_palette_light_green_100",
  "global_palette_light_green_200",
  "global_palette_light_green_300",
  "global_palette_light_green_400",
  "global_palette_light_green_500",
  "global_palette_light_green_600",
  "global_palette_light_green_700",
  "global_palette_orange_100",
  "global_palette_orange_200",
  "global_palette_orange_300",
  "global_palette_orange_400",
  "global_palette_orange_50",
  "global_palette_orange_500",
  "global_palette_orange_600",
  "global_palette_orange_700",
  "global_palette_purple_100",
  "global_palette_purple_200",
  "global_palette_purple_300",
  "global_palette_purple_400",
  "global_palette_purple_50",
  "global_palette_purple_500",
  "global_palette_purple_600",
  "global_palette_purple_700",
  "global_palette_red_100",
  "global_palette_red_200",
  "global_palette_red_300",
  "global_palette_red_400",
  "global_palette_red_50",
  "global_palette_red_500",
  "global_palette_white",
  "global_primary_color_100",
  "global_primary_color_200",
  "global_primary_color_dark_100",
  "global_primary_color_light_100",
  "global_secondary_color_100",
  "global_success_color_100",
  "global_success_color_200",
  "global_warning_color_100",
  "global_warning_color_200",
]);
